==> haskell-githash-0.1.6.3-336-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-4qZQLgXLtE3IVCVa8zq2mC
key:                  githash-0.1.6.3-4qZQLgXLtE3IVCVa8zq2mC
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  91d1591fbff4d4ab86a0b1396565a361
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-4qZQLgXLtE3IVCVa8zq2mC
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 process-1.6.19.0 template-haskell-2.20.0.0
    th-compat-0.1.6-GpjIKGc0GPMFBEveh1mM8h

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-githash-0.1.6.3-337-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-L5VTSr5LQebIEYHHLt617w
key:                  githash-0.1.6.3-L5VTSr5LQebIEYHHLt617w
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  bd26b0811b53aec3c2576e7cee84f253
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-L5VTSr5LQebIEYHHLt617w
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 process-1.6.19.0 template-haskell-2.20.0.0
    th-compat-0.1.6-KectvLb9yylAlpm8iQXOj

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
